@@ -1,5 +1,7 @@
-__version__ = "0.2.0"
+__version__ = "0.4.1"
 
+from bigtree.dag.construct import dataframe_to_dag, dict_to_dag, list_to_dag
+from bigtree.dag.export import dag_to_dataframe, dag_to_dict, dag_to_dot, dag_to_list
 from bigtree.node.basenode import BaseNode
 from bigtree.node.dagnode import DAGNode
 from bigtree.node.node import Node
@@ -12,10 +14,10 @@ from bigtree.tree.construct import (
     dataframe_to_tree,
     dict_to_tree,
     list_to_tree,
+    list_to_tree_tuples,
     nested_dict_to_tree,
 )
 from bigtree.tree.export import (
-    dag_to_dot,
     print_tree,
     tree_to_dataframe,
     tree_to_dict,
@@ -51,6 +53,7 @@ from bigtree.utils.exceptions import (
     TreeError,
 )
 from bigtree.utils.iterators import (
+    dag_iterator,
     levelorder_iter,
     levelordergroup_iter,
     postorder_iter,
