@@ -1,6 +1,7 @@
 from collections import OrderedDict
-from typing import Type
+from typing import List, Tuple, Type
 
+import numpy as np
 import pandas as pd
 
 from bigtree.node.node import Node
@@ -14,6 +15,7 @@ __all__ = [
     "add_dict_to_tree_by_name",
     "add_dataframe_to_tree_by_path",
     "add_dataframe_to_tree_by_name",
+    "list_to_tree_tuples",
     "list_to_tree",
     "dict_to_tree",
     "nested_dict_to_tree",
@@ -280,10 +282,10 @@ def add_dataframe_to_tree_by_path(
         attribute_cols.remove(path_col)
 
     tree_root = tree.root
-    data = data.copy()[[path_col] + attribute_cols].drop_duplicates()
     data[path_col] = data[path_col].str.lstrip(sep).str.rstrip(sep)
+    data2 = data.copy()[[path_col] + attribute_cols].astype(str).drop_duplicates()
     _duplicate_check = (
-        data[path_col]
+        data2[path_col]
         .value_counts()
         .to_frame("counts")
         .rename_axis(path_col)
@@ -298,7 +300,7 @@ def add_dataframe_to_tree_by_path(
     for row in data.to_dict(orient="index").values():
         node_attrs = row.copy()
         del node_attrs[path_col]
-        node_attrs = {k: v for k, v in node_attrs.items() if not pd.isnull(v)}
+        node_attrs = {k: v for k, v in node_attrs.items() if not np.any(pd.isnull(v))}
         add_path_to_tree(
             tree_root,
             row[path_col],
@@ -369,9 +371,9 @@ def add_dataframe_to_tree_by_name(
 
     # Attribute data
     path_col = "PATH"
-    data = data.copy()[[name_col] + attribute_cols].drop_duplicates()
+    data2 = data.copy()[[name_col] + attribute_cols].astype(str).drop_duplicates()
     _duplicate_check = (
-        data[name_col]
+        data2[name_col]
         .value_counts()
         .to_frame("counts")
         .rename_axis(name_col)
@@ -380,7 +382,7 @@ def add_dataframe_to_tree_by_name(
     _duplicate_check = _duplicate_check[_duplicate_check["counts"] > 1]
     if len(_duplicate_check):
         raise ValueError(
-            f"There exists duplicate path with different attributes\nCheck {_duplicate_check}"
+            f"There exists duplicate name with different attributes\nCheck {_duplicate_check}"
         )
 
     # Tree data
@@ -402,6 +404,49 @@ def add_dataframe_to_tree_by_name(
     )
 
 
+def list_to_tree_tuples(
+    relations: List[Tuple[str, str]],
+    node_type: Type[Node] = Node,
+) -> Node:
+    """Construct tree from list of tuple containing parent-child names.
+
+    >>> from bigtree import list_to_tree_tuples, print_tree
+    >>> relations_list = [("a", "b"), ("a", "c"), ("b", "d"), ("b", "e"), ("c", "f"), ("e", "g"), ("e", "h")]
+    >>> root = list_to_tree_tuples(relations_list)
+    >>> print_tree(root)
+    a
+    |-- b
+    |   |-- d
+    |   `-- e
+    |       |-- g
+    |       `-- h
+    `-- c
+        `-- f
+
+    Args:
+        relations (list): list containing tuple containing parent-child names
+        node_type (Type[Node]): node type of tree to be created, defaults to Node
+
+    Returns:
+        (Node)
+    """
+    if not len(relations):
+        raise ValueError("Path list does not contain any data, check `relations`")
+
+    node_dict = {}
+    for parent_name, child_name in relations:
+        if not node_dict.get(parent_name):
+            node_dict[parent_name] = node_type(parent_name)
+        if not node_dict.get(child_name):
+            node_dict[child_name] = node_type(child_name)
+
+        parent_node = node_dict[parent_name]
+        child_node = node_dict[child_name]
+        child_node.parent = parent_node
+    root = child_node.root
+    return root
+
+
 def list_to_tree(
     paths: list,
     sep: str = "/",
@@ -655,10 +700,10 @@ def dataframe_to_tree(
         attribute_cols = list(data.columns)
         attribute_cols.remove(path_col)
 
-    data = data.copy()[[path_col] + attribute_cols].drop_duplicates()
     data[path_col] = data[path_col].str.lstrip(sep).str.rstrip(sep)
+    data2 = data.copy()[[path_col] + attribute_cols].astype(str).drop_duplicates()
     _duplicate_check = (
-        data[path_col]
+        data2[path_col]
         .value_counts()
         .to_frame("counts")
         .rename_axis(path_col)
