@@ -14,6 +14,7 @@ from bigtree.tree.construct import (
     dataframe_to_tree,
     dict_to_tree,
     list_to_tree,
+    list_to_tree_tuples,
     nested_dict_to_tree,
 )
 from bigtree.utils.exceptions import DuplicatedNodeError, TreeError
@@ -825,6 +826,47 @@ class TestAddDataFrameToTreeByName(unittest.TestCase):
         assert_tree_structure_basenode_root_attr(root)
 
 
+class TestListToTreeTuples(unittest.TestCase):
+    def setUp(self):
+        """
+        Tree should have structure
+        a
+        |-- b
+        |   |-- d
+        |   +-- e
+        |       |-- g
+        |       +-- h
+        +-- c
+            +-- f
+        """
+        self.relations = [
+            ("a", "b"),
+            ("a", "c"),
+            ("b", "d"),
+            ("b", "e"),
+            ("c", "f"),
+            ("e", "g"),
+            ("e", "h"),
+        ]
+
+    def tearDown(self):
+        self.relations = None
+
+    def test_list_to_tree_tuples(self):
+        root = list_to_tree_tuples(self.relations)
+        assert_tree_structure_basenode_root_generic(root)
+        assert_tree_structure_node_root_generic(root)
+
+    def test_list_to_tree_tuples_reversed(self):
+        root = list_to_tree_tuples(self.relations[::-1])
+        assert_tree_structure_basenode_root_generic(root)
+        assert_tree_structure_node_root_generic(root)
+
+    def test_list_to_tree_tuples_empty(self):
+        with pytest.raises(ValueError):
+            list_to_tree_tuples([])
+
+
 class TestListToTree(unittest.TestCase):
     def setUp(self):
         """
@@ -1227,17 +1269,20 @@ class TestDataFrameToTree(unittest.TestCase):
         root = dataframe_to_tree(path_data)
         assert_tree_structure_basenode_root_generic(root)
 
-    def test_dataframe_to_tree_empty_row(self):
+    @staticmethod
+    def test_dataframe_to_tree_empty_row():
         data = pd.DataFrame(columns=["PATH", "age"])
         with pytest.raises(ValueError):
             dataframe_to_tree(data)
 
-    def test_dataframe_to_tree_empty_col(self):
+    @staticmethod
+    def test_dataframe_to_tree_empty_col():
         data = pd.DataFrame()
         with pytest.raises(ValueError):
             dataframe_to_tree(data)
 
-    def test_dataframe_to_tree_sep_leading(self):
+    @staticmethod
+    def test_dataframe_to_tree_sep_leading():
         data = pd.DataFrame(
             [
                 ["/a", 90],
